#if DEBUG

// The following code was generated by Microsoft Visual Studio 2005.
// The test owner should check each test for validity.
using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace DirClean.UnitTests
{
    [TestClass]
    public class UnitTests
    {
        private static TextWriter _normalOutput;

        private static string _rootPath;
        private static string _subDir1;
        private static StringWriter _testingConsole;
        private static StringBuilder _testingSB;

        /// <summary>
        /// Tests passing only tno arguments.
        /// When no args are passed the help text should be displayed.
        /// </summary>
        [TestMethod]
        public void TestNoArgs()
        {
            // Check exit is normal
            Assert.AreEqual(0, this.StartConsoleApplication(string.Empty));

            // Check that help information shown correctly.
            Assert.IsTrue(_testingSB.ToString() == (Constants.HELP_TEXT));
        }


        /// <summary>
        /// Tests passing only the help text option
        /// </summary>
        [TestMethod]
        public void TestHelpText()
        {
            // Check exit is normal
            Assert.AreEqual(0, this.StartConsoleApplication(Constants.HELP));

            // Check that help information shown correctly.
            Assert.IsTrue(_testingSB.ToString() == (Constants.HELP_TEXT));
        }


        /// <summary>
        /// Tests passing the HELP switch with the SILENT switch.
        /// Help text should still be displayed even when SILENT switch is passed.
        /// </summary>
        [TestMethod]
        public void TestHelpTextWithSilent()
        {
            // Check exit is normal
            Assert.AreEqual(0, this.StartConsoleApplication(Constants.HELP + " " + Constants.SILENT));

            // Check that help information shown correctly.
            Assert.IsTrue(_testingSB.ToString() == (Constants.HELP_TEXT));
        }


        /// <summary>
        /// Tests passing the INITIAL DIR switch with the LOG TO CONSOLE switch.
        /// Should check in the root dir and find no files but will find some folders
        /// and since RECURSIVE switch is not passed this will result in no empty dirs
        /// being logged to the console.
        /// </summary>
        [TestMethod]
        public void TestLogDirsToConsole()
        {
            // Check exit is normal
            Assert.AreEqual(0,
                            this.StartConsoleApplication(Constants.INITIAL_DIR + " \"" + _rootPath + "\" " +
                                                         Constants.LOG_TO_CONSOLE));

            // Check that help information shown correctly.
            Assert.IsTrue(_testingSB.ToString() ==
                          ("\nThe following directories are empty...\n\n\tNone found!\n\nPress enter to quit..."));
        }


        /// <summary>
        /// Tests passing the INITIAL DIR switch with the LOG TO CONSOLE switch.
        /// Should check in the root dir and find no files but will find some folders
        /// and since RECURSIVE switch is not pass this will result in no empty dirs
        /// being logged to the console.
        /// </summary>
        [TestMethod]
        public void TestRecursiveLogDirsToConsole()
        {
            // Check exit is normal
            Assert.AreEqual(0,
                            this.StartConsoleApplication(Constants.INITIAL_DIR + " \"" + _rootPath + "\" " +
                                                         Constants.LOG_TO_CONSOLE + " " + Constants.RECURSIVE));

            // Check that help information shown correctly.
            Assert.IsTrue(_testingSB.ToString() ==
                          ("..\nThe following directories are empty...\n\n\t" + _rootPath + "\n\t" + _subDir1 +
                           "\n\n\nPress enter to quit..."));
        }


        /// <summary>
        /// Starts the console application.
        /// </summary>
        /// <param name="arguments">The arguments for console application. 
        /// Specify empty string to run with no arguments</PARAM />
        /// <returns>exit code</returns>
        private int StartConsoleApplication(string arguments)
        {
            // Initialize process here
            var proc = new Process();
            proc.StartInfo.FileName = "DirClean.exe";
            // add arguments as whole string
            proc.StartInfo.Arguments = arguments;

            // use it to start from testing environment
            proc.StartInfo.UseShellExecute = false;

            // redirect outputs to have it in testing console
            proc.StartInfo.RedirectStandardOutput = true;
            proc.StartInfo.RedirectStandardError = true;

            // set working directory
            proc.StartInfo.WorkingDirectory = Environment.CurrentDirectory;

            // start and wait for exit
            proc.Start();
            proc.WaitForExit();

            _testingSB.Append(proc.StandardOutput.ReadToEnd());
            _testingSB.Append(proc.StandardError.ReadToEnd());

            // get output to testing console.
            Console.Write(_testingSB.ToString());

            // return exit code
            return proc.ExitCode;
        }


        /// <summary>
        /// This is run automatically by the 
        /// nUnit framework before each test.
        /// </summary>
        [TestInitialize]
        public void SetUp()
        {
            Debug.WriteLine(Assembly.GetExecutingAssembly().FullName);

            // clear string builder
            _testingSB.Remove(0, _testingSB.Length);

            #region CREATE TEST FOLDER STRUCTURE

            _rootPath = Path.Combine(Environment.CurrentDirectory, "testRoot");
            _subDir1 = Path.Combine(_rootPath, "subDir1");

            Directory.CreateDirectory(_rootPath);
            Directory.CreateDirectory(_subDir1);

            #endregion
        }


        /// <summary>
        /// This is run automatically by the 
        /// nUnit framework after each test.
        /// </summary>
        [TestCleanup]
        public void TearDown()
        {
            // Verbose output in console
            //_normalOutput.Write(_testingSB.ToString());


            // Delete test folder structure
            Directory.Delete(Path.Combine(Environment.CurrentDirectory, "testRoot"), true);
        }


        /// <summary>
        /// This is run once by the nUnit 
        /// framework when the test run starts.
        /// </summary>
        [ClassInitialize]
        public static void TestFixtureSetUp(TestContext testContext)
        {
            // Set current folder to testing folder
            string assemblyCodeBase = Assembly.GetExecutingAssembly().CodeBase;

            // Get directory name
            string dirName = Path.GetDirectoryName(assemblyCodeBase);

            // remove URL-prefix if it exists
            if (dirName.StartsWith("file:\\"))
            {
                dirName = dirName.Substring(6);
            }

            // set current folder
            Environment.CurrentDirectory = dirName;

            // Initialize string builder to replace console
            _testingSB = new StringBuilder();
            _testingConsole = new StringWriter(_testingSB);

            // swap normal output console with testing console - to reuse 
            // it later
            _normalOutput = Console.Out;
            _normalOutput.Flush();
            Console.SetOut(_testingConsole);
        }


        /// <summary>
        /// This is run once by the nUnit 
        /// framework when the test run finishes.
        /// </summary>
        [ClassCleanup]
        public static void TestFixtureTearDown()
        {
            // set normal output stream to the console
            Console.SetOut(_normalOutput);
        }
    }
}

#endif